@@ -1,6 +1,6 @@
 /*
  * backend.h -- Interface exported by XBoard back end
- * $Id: backend.h,v 1.27 1996/11/17 05:57:41 mann Exp $
+ * $Id: backend.h,v 1.31 1997/05/09 04:25:48 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -48,8 +48,9 @@
 #include "lists.h"
 
 extern GameMode gameMode;
-extern int pausing, cmailMsgLoaded, flipView, ics_bughouse;
-extern FILE *fromUserFP, *toUserFP, *debugFP;
+extern int pausing, cmailMsgLoaded, flipView, ics_bughouse, ics_suicide;
+extern FILE *debugFP;
+extern char* programVersion;
 
 void TimeDelay P((long ms));
 void SendMultiLineToICS P(( char *text ));
@@ -87,6 +88,7 @@ void PauseEvent P((void));
 void CallFlagEvent P((void));
 void AcceptEvent P((void));
 void DeclineEvent P((void));
+void RematchEvent P((void));
 void DrawEvent P((void));
 void AbortEvent P((void));
 void AdjournEvent P((void));
@@ -107,7 +109,7 @@ void LoadGameLoop P((void));
 void DisplayBothClocks P((void));
 void EditPositionMenuEvent P((ChessSquare selection, int x, int y));
 void DropMenuEvent P((ChessSquare selection, int x, int y));
-int ParseTimeControl P((char *tc));
+int ParseTimeControl P((char *tc, int ti, int mps));
 void ProcessICSInitScript P((FILE * f));
 void EditCommentEvent P((void));
 void ReplaceComment P((int index, char *text));
@@ -120,8 +122,12 @@ void GetMoveListEvent P((void));
 void ExitAnalyzeMode P((void));
 void AnalyzeModeEvent P((void));
 void AnalyzeFileEvent P((void));
+void DoEcho P((void));
+void DontEcho P((void));
+void TidyProgramName P((char *prog, char *host, char *buf));
 
 char *StrStr P((char *string, char *match));
+char *StrCaseStr P((char *string, char *match));
 char *StrSave P((char *s));
 char *StrSavePtr P((char *s, char **savePtr));
 
@@ -137,7 +143,6 @@ int ToUpper P((int c));
 extern GameInfo gameInfo;
 
 
-
 /* pgntags.c prototypes
  */
 char *PGNTags P((GameInfo *));
