@@ -1,6 +1,6 @@
 /*
  * frontend.h -- Interface exported by all XBoard front ends
- * $Id: frontend.h,v 1.18 1996/11/17 05:57:41 mann Exp $
+ * $Id: frontend.h,v 1.21 1997/05/04 04:09:20 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -51,6 +51,10 @@
 
 #include <stdio.h>
 
+typedef VOIDSTAR ProcRef;
+#define NoProc ((ProcRef) 0)
+typedef VOIDSTAR InputSourceRef;
+
 void ModeHighlight P((void));
 void SetICSMode P((void));
 void SetGNUMode P((void));
@@ -61,6 +65,8 @@ void DisplayMessage P((String message, String extMessage));
 void DisplayError P((String message, int error));
 void DisplayFatalError P((String message, int error, int status));
 void DisplayInformation P((String message));
+void AskQuestion P((String title, String question, String replyPrefix,
+		    ProcRef pr));
 void DrawPosition P((int fullRedraw, Board board));
 void ResetFrontEnd P((void));
 void CommentPopUp P((String title, String comment));
@@ -71,6 +77,7 @@ void RingBell P((void));
 void EchoOn P((void));
 void EchoOff P((void));
 void Raw P((void));
+void Colorize P((ColorClass cc));
 
 char *UserName P((void));
 char *HostName P((void));
@@ -86,8 +93,6 @@ int StopLoadGameTimer P((void));
 void StartLoadGameTimer P((long millisec));
 void AutoSaveGame P((void));
 
-typedef VOIDSTAR ProcRef;
-#define NoProc ((ProcRef) 0)
 int StartChildProcess P((char *cmdLine, ProcRef *pr));
 void DestroyChildProcess P((ProcRef pr));
 void InterruptChildProcess P((ProcRef pr));
@@ -98,11 +103,12 @@ int OpenCommPort P((char *name, ProcRef *pr));
 int OpenLoopback P((ProcRef *pr));
 int OpenRcmd P((char *host, char *user, char *cmd, ProcRef *pr));
 
-typedef VOIDSTAR InputSourceRef;
 typedef void (*InputCallback) P((InputSourceRef isr, char *buf, int count, int error));
+/* pr == NoProc means the local keyboard */
 InputSourceRef AddInputSource P((ProcRef pr, int lineByLine, InputCallback func));
 void RemoveInputSource P((InputSourceRef isr));
 
+/* pr == NoProc means the local display */
 int OutputToProcess P((ProcRef pr, char *message, int count, int *outError));
 int OutputToProcessDelayed P((ProcRef pr, char *message, int count,
 			      int *outError, long msdelay));
