@@ -1,6 +1,6 @@
 /*
  * xboard.h -- Parameter definitions for X front end
- * $Id: xboard.h,v 1.19 1996/12/19 22:42:52 mann Exp $
+ * $Id: xboard.h,v 1.20 1997/04/13 06:31:29 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -56,6 +56,14 @@
 #define DEFAULT_FONT "*font: -*-helvetica-medium-r-normal--14-*-*-*-*-*-*-*"
 #define TINY_FONT \
     "*tinyLayout*font: -*-helvetica-medium-r-normal--11-*-*-*-*-*-*-*"
+#define COLOR_SHOUT             "green"
+#define COLOR_SSHOUT            "green,black,1"
+#define COLOR_CHANNEL1          "cyan"
+#define COLOR_CHANNEL           "cyan,black,1"
+#define COLOR_KIBITZ            "magenta,black,1"
+#define COLOR_TELL              "yellow,black,1"
+#define COLOR_CHALLENGE         "red,black,1"
+#define COLOR_NORMAL            "default"
 
 typedef struct {
     char *name;
