@@ -1,6 +1,6 @@
 /*
  * zippy.c -- Implements Zippy the Pinhead chess player on ICS in XBoard
- * $Id: zippy.c,v 1.35 1997/01/01 23:40:46 mann Exp $
+ * $Id: zippy.c,v 1.38 1997/05/09 04:27:25 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -100,6 +100,7 @@ extern char *getenv();
 extern void SendTimeRemaining P((ProcRef pr));
 
 static char zippyName[MSG_SIZ];
+static char zippyPinhead[MSG_SIZ];
 static char zippyPassword[MSG_SIZ];
 static int zippyPasswordLength;
 static char zippyPassword2[MSG_SIZ];
@@ -108,7 +109,6 @@ static char zippyWrongPassword[MSG_SIZ];
 static int zippyWrongPasswordLength;
 static char zippyAcceptOnly[MSG_SIZ];
 static int zippyAcceptOnlyLength;
-static int gnuLevel;
 static int zippyUseI;
 
 void ZippyInit()
@@ -119,10 +119,17 @@ void ZippyInit()
        this is automatically reset to the name we are logged in as. */
     p = getenv("ZIPPYNAME");
     if (p == NULL)
-      strcpy(zippyName, "Zippy");
+      strcpy(zippyName, "");
     else
       strcpy(zippyName, p);
 
+    /* Get word that Zippy thinks is insulting */
+    p = getenv("ZIPPYPINHEAD");
+    if (p == NULL)
+      strcpy(zippyPinhead, "");
+    else
+      strcpy(zippyPinhead, p);
+
     /* What password is used for remote control? */
     p = getenv("ZIPPYPASSWORD");
     if (p != NULL)
@@ -153,17 +160,6 @@ void ZippyInit()
       zippyAcceptOnlyLength = 0;
     }
     
-    /* Modify behavior for different chess programs:
-       0 = GNU Chess 4.0 pl 66 or earlier. 
-       1 = GNU Chess 4.0 pl 67 or later, or Crafty.  DEFAULT
-    */
-    p = getenv("ZIPPYGNULEVEL");
-    if (p == NULL) {
-	gnuLevel = 1;
-    } else {
-	gnuLevel = atoi(p);
-    }
-
     /* Should Zippy use "i" command? */
     /* Defaults to 1=true */
     p = getenv("ZIPPYUSEI");
@@ -180,23 +176,6 @@ void ZippyInit()
  * Routines to implement Zippy talking
  */
 
-char *StrCaseStr(string, match)
-     char *string, *match;
-{
-    int i, j, length;
-    
-    length = strlen(match);
-    
-    for (i = strlen(string) - length; i >= 0; i--, string++) {
-	for (j = 0; j < length; j++) {
-	    if (ToLower(match[j]) != ToLower(string[j]))
-	      break;
-	}
-	if (j == length) return string;
-    }
-
-    return NULL;
-}
 
 char *swifties[] = { 
     "i admonishes:", "i advertises:", "i advises:", "i affirms:",
@@ -366,7 +345,7 @@ void Speak(how, whom)
 int ZippyCalled(str)
      char *str;
 {
-    return StrCaseStr(str, zippyName) != NULL;
+    return zippyName[0] != NULLCHAR && StrCaseStr(str, zippyName) != NULL;
 }
 
 int ZippyControl(buf, i)
@@ -433,7 +412,8 @@ int ZippyConverse(buf, i)
 	    if (borecount++ % 5 == 0)
 	      SendToICS("shout Norm is a BORE!  I am a PINHEAD!\n");
 	    Speak("shout", NULL);
-	} else if (StrCaseStr(star_match[1], "pinhead") != NULL) {
+	} else if (zippyPinhead[0] != NULLCHAR &&
+		   StrCaseStr(star_match[1], zippyPinhead) != NULL) {
 	    SendToICS("insult ");
 	    SendToICS(star_match[0]);
 	    SendToICS("\n");
@@ -457,7 +437,7 @@ int ZippyConverse(buf, i)
 	 atoi(star_match[0]) != 0) ||
 	looking_at(buf, i, "* has left a message for you.") ||
 	looking_at(buf, i, "* just sent you a message.")) {
-	SendToICS("messages\nclearmessages\n");
+	SendToICS("messages\nclearmessages\nclearmessages *\n");
 	return TRUE;
     }
 
@@ -521,6 +501,14 @@ void ZippyGameStart(white, black)
     /* do nothing */
 }
 
+void ZippyGameEnd(result, resultDetails)
+     ChessMove result;
+     char *resultDetails;
+{
+    if (zippyAcceptOnlyLength == 0)
+      SendToICS("gameend\n");  /* you can alias this */
+}
+
 /*
  * Routines to implement Zippy playing chess
  */
@@ -537,7 +525,7 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
 	char* dwild;
 	if ((dwild = (char *)strchr(swild, '(')) != NULL ||
 	    (dwild = (char *)strchr(swild, '/')) != NULL) {
-	    wild = atoi(dwild) + 1;
+	    wild = atoi(dwild + 1);
 	} else {
 	    /* Challenge message not understood */
 	    return;
@@ -552,17 +540,18 @@ void ZippyHandleChallenge(srated, swild, sbase, sincrement, opponent)
     if ( zippyAcceptOnlyLength > 0 && StrCaseCmp(opponent, zippyAcceptOnly) )
       {
 	sprintf( buf, "tell %s %s\ndecline %s\n", opponent,
-		"Sorry, I'm testing xboard and cannot accept matches now.",
+		"Sorry, I'm testing and cannot accept matches now.",
 		opponent );
 	SendToICS( buf );
 	return;
       }
     
-    if (wild == 1 || wild == 9 || wild == 16 || wild == 24) {
-	/* Wild 1, 9, 16, and 24 have different rules from normal chess.
+    if (wild == 1 || wild == 9 || wild == 16 || wild == 17 || wild == 24) {
+	/* Wild variants that have different rules from normal chess.
 	   In wild 1, you can sometimes castle with the king on the d file.
 	   In wild 9, there are two kings per side and rules are bizarre.
 	   In wild 16 (kriegspiel), you can't see your opponent's pieces.
+	   Wild 17 is loser's chess.
 	   Wild 24 is bughouse.
 	   GNU Chess can't handle these things.
 	*/
@@ -689,51 +678,22 @@ int ZippyMatch(buf, i)
     return FALSE;
 }
 
-/* This is needed only for gnuchess 4.0 pl62 and earlier; later versions
-   do the estimation inside gnuchess */
-int EstimateMoves(minutes)
-     int minutes;
-{
-    static int Nmoves[] = {0, 50, 50, 50, 50, 50, 50, 52, 54, 56, 60, 64, 68,
-			     72, 76, 80, 84, 88, 90, 94, 98}; /*!!*/
-
-    if (minutes >= sizeof(Nmoves) / sizeof(int)) {
-	return Nmoves[sizeof(Nmoves) / sizeof(int) - 1];
-    } else {
-	return Nmoves[minutes];
-    }
-}
-
 void ZippyFirstBoard(moveNum, basetime, increment)
      int moveNum, basetime, increment;
 {
     char buf[MSG_SIZ];
     int w, b;
 
-    /* Get chess program going */
-    if (startedFromSetupPosition || moveNum > 0) {
-	/* !! In the moveNum > 0 case we really should
-	   wait for the game history to come in and give
-	   the program that, because the position doesn't
-	   give us the whole story (about castling, en
-	   passant, 50 move rule, and repetition).
-	   */
+    /* Initialize chess program with data from the first board 
+       of a new or resumed game */
+
+    if (startedFromSetupPosition || (!appData.getMoveList && moveNum > 0)) {
 	if (!WhiteOnMove(moveNum))
 	  SendToProgram("force\na2a3\n", firstProgramPR);
-
 	SendCurrentBoard(firstProgramPR);
     }
 
-    if (gnuLevel == 0) {
-	if (increment == 0) {
-	    sprintf(buf, "gamein\nlevel %d %d\n",
-		    EstimateMoves(basetime), basetime);
-	} else {
-	    sprintf(buf, "gamein\nlevel f %d %d\n", basetime, increment);
-	}
-    } else {
-	sprintf(buf, "level 0 %d %d\n", basetime, increment);
-    } 
+    sprintf(buf, "level 0 %d %d\n", basetime, increment);
     SendToProgram(buf, firstProgramPR);
     SendTimeRemaining(firstProgramPR);
 
@@ -749,10 +709,19 @@ void ZippyFirstBoard(moveNum, basetime, increment)
 	strcpy(zippyName, gameInfo.white);
 	sprintf(buf, "rating %d %d\n", w, b);
 	SendToProgram(buf, firstProgramPR);
-	if (WhiteOnMove(moveNum)) {
-	    SendToProgram(appData.whiteString, firstProgramPR);
+	if (appData.getMoveList) {
+	    /* Resume from adjournments with move list, to be sent later */
+	    if (moveNum == 0) {
+		/* Not an adjournment */
+		SendToProgram(appData.whiteString, firstProgramPR);
+	    }
 	} else {
-	    firstMove = TRUE; /* need to send whiteString later */
+	    /* Resume from adjournments with position only, sent above */
+	    if (WhiteOnMove(moveNum)) {
+		SendToProgram(appData.whiteString, firstProgramPR);
+	    } else {
+		firstMove = TRUE; /* need to send whiteString later */
+	    }
 	}
     } else if (gameMode == IcsPlayingBlack) {
 	sprintf(buf, "name %s\n", gameInfo.white);
@@ -760,10 +729,16 @@ void ZippyFirstBoard(moveNum, basetime, increment)
 	strcpy(zippyName, gameInfo.black);
 	sprintf(buf, "rating %d %d\n", b, w );
 	SendToProgram(buf, firstProgramPR);
-	if (!WhiteOnMove(moveNum)) {
-	    SendToProgram(appData.blackString, firstProgramPR);
+	if (appData.getMoveList) {
+	    /* Resume from adjournments with move list, to be sent later */
+	    /* Nothing to do here */
 	} else {
-	    /* nothing to do */
+	    /* Resume from adjournments with position only, sent above */
+	    if (!WhiteOnMove(moveNum)) {
+		SendToProgram(appData.blackString, firstProgramPR);
+	    } else {
+		/* nothing to do here */
+	    }
 	}
     }
 }
